# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.1.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.2.0] - 2026-03-23


### Added

- V0.1.0 release polish - critical and major fixes

- **screening:** Add global top-percent selection for deep analysis 


### Documentation

- **readme:** Update config and screening mode guidance


### Fixed

- **s2:** Enforce 1 rps throttling across S2 stages


### Maintenance

- Migrate to opencode workflow


### ci

- **release:** Add environment for trusted publisher


## [0.1.0] - 2026-03-09


### Added

- **ci:** Add oss release workflows


### Maintenance

- Initial project setup

- Release v0.1.0

